@@ -31,21 +31,20 @@
 package SNMP::Info::Layer2::HPVC;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer2;
-use SNMP::Info::LLDP;
 
 @SNMP::Info::Layer2::HPVC::ISA
-    = qw/SNMP::Info::Layer2 SNMP::Info::LLDP Exporter/;
+    = qw/SNMP::Info::Layer2 Exporter/;
 @SNMP::Info::Layer2::HPVC::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.85';
 
 %MIBS = (
     %SNMP::Info::Layer2::MIBS,
-    %SNMP::Info::LLDP::MIBS,
     'HPVC-MIB'       => 'vcDomainName',
     'CPQSINFO-MIB'   => 'cpqSiSysSerialNum',
     'HPVCMODULE-MIB' => 'vcModuleDomainName',
@@ -53,7 +52,6 @@ $VERSION = '3.53';
 
 %GLOBALS = (
     %SNMP::Info::Layer2::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,
     'serial1'      => 'cpqSiSysSerialNum.0',
     'os_ver'       => 'cpqHoSWRunningVersion.1',
     'os_bin'       => 'cpqHoFwVerVersion.1',
@@ -62,17 +60,13 @@ $VERSION = '3.53';
 
 %FUNCS = (
     %SNMP::Info::Layer2::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,
-    
 );
 
 %MUNGE = (
     # Inherit all the built in munging
     %SNMP::Info::Layer2::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,
 );
 
-
 # Method Overrides
 
 sub os {
@@ -102,14 +96,14 @@ Jeroen van Ingen
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $hp = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $hp->class();
@@ -117,13 +111,8 @@ Jeroen van Ingen
 
 =head1 DESCRIPTION
 
-Provides abstraction to the configuration information obtainable from a 
-HP Virtual Connect Switch via SNMP. 
-
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
-
- my $hp = new SNMP::Info::Layer2::HPVC(...);
+Provides abstraction to the configuration information obtainable from a
+HP Virtual Connect Switch via SNMP.
 
 =head2 Inherited Classes
 
@@ -188,27 +177,15 @@ See documentation in L<SNMP::Info::Layer2/"GLOBALS"> for details.
 These are methods that return tables of information in the form of a reference
 to a hash.
 
-=head2 Overrides
-
-=over
-
-=back
-
 =head2 Table Methods imported from SNMP::Info::Layer2
 
 See documentation in L<SNMP::Info::Layer2/"TABLE METHODS"> for details.
 
-=head1 MUNGES
-
-=over
-
-=back
-
 =head1 SET METHODS
 
 These are methods that provide SNMP set functionality for overridden methods
 or provide a simpler interface to complex set operations.  See
 L<SNMP::Info/"SETTING DATA VIA SNMP"> for general information on set
-operations. 
+operations.
 
 =cut
