@@ -38,7 +38,7 @@ use SNMP::Info::Layer3;
 
 our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.76';
+$VERSION = '3.85';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -74,6 +74,18 @@ $VERSION = '3.76';
 
 %MUNGE = ( %SNMP::Info::Layer3::MUNGE, );
 
+sub layers {
+    my $dlink = shift;
+
+    my $layers = $dlink->SUPER::layers();
+    if ($layers) {
+        substr $layers, 5, 1, "1";
+        substr $layers, 6, 1, "1";
+    }
+
+    return $layers;
+}
+
 sub model {
     my $dlink=shift;
     my $id = $dlink->id();
@@ -233,6 +245,10 @@ These are methods that return scalar value from SNMP
 
 =over
 
+=item $dlink->layers()
+
+Makes sure to always report layer 2 and 3.
+
 =item $dlink->model()
 
 Returns the ID or else description.
