@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::Microsoft
-# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -31,15 +30,16 @@
 package SNMP::Info::Layer3::Microsoft;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 
 @SNMP::Info::Layer3::Microsoft::ISA       = qw/SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::Microsoft::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '2.06';
+$VERSION = '3.85';
 
 %MIBS = ( %SNMP::Info::Layer3::MIBS, );
 
@@ -96,7 +96,7 @@ __END__
 
 =head1 NAME
 
-SNMP::Info::Layer3::Microsoft - SNMP Interface to L3 Microsoft Windows router
+SNMP::Info::Layer3::Microsoft - SNMP Interface to L3 Microsoft Windows routers
 
 =head1 AUTHOR
 
@@ -104,14 +104,14 @@ begemot
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $router = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myrouter',
                           Community   => 'public',
-                          Version     => 1
-                        ) 
+                          Version     => 2
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $router->class();
